"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.client = void 0;
const routes_1 = require("./routes");
const request_1 = require("../utils/request");
const constants_1 = __importDefault(require("../constants"));
const formatAuthHeader = (sessionToken) => ({
    [constants_1.default.USER_AUTH_HEADER_NAME]: sessionToken,
});
function login(email, password) {
    return __awaiter(this, void 0, void 0, function* () {
        // Perform login request.
        const { data, headers, error } = yield (0, request_1.post)((0, routes_1.buildUrl)(routes_1.routes.LOGIN), { email, password });
        if (error)
            return { error };
        // Get new session token from response headers.
        const sessionToken = headers.get(constants_1.default.USER_AUTH_HEADER_NAME);
        return { sessionToken, message: data.message };
    });
}
function getProject(namespace, project, sessionToken) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        // Perform link request.
        const { data, error } = yield (0, request_1.get)((0, routes_1.buildUrl)(routes_1.routes.GET_PROJECT), { namespace, project }, formatAuthHeader(sessionToken));
        if (error)
            return { error };
        // Return project info.
        return {
            id: data.id || '',
            name: data.slug || '',
            namespace: ((_a = data.namespace) === null || _a === void 0 ? void 0 : _a.name) || '',
            apiKey: data.apiKey,
            metadata: data.metadata || {},
        };
    });
}
function logs(projectId, sessionToken, tail, env) {
    return __awaiter(this, void 0, void 0, function* () {
        const params = { id: projectId, tail: tail };
        if (env) {
            params.env = env;
        }
        // Perform logs request.
        const { data: resp, error } = yield (0, request_1.get)((0, routes_1.buildUrl)(routes_1.routes.PROJECT_LOGS), params, formatAuthHeader(sessionToken), true);
        if (error)
            return { error };
        if ((resp === null || resp === void 0 ? void 0 : resp.status) !== 200) {
            return { error: `Request failed with status ${resp === null || resp === void 0 ? void 0 : resp.status}.` };
        }
        return { data: resp.body };
    });
}
function getAbi(group) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data: resp, error } = yield (0, request_1.get)((0, routes_1.buildUrl)(routes_1.routes.GET_ABI), { group }, {}, false);
        return error ? { error } : { abi: resp.abi ? JSON.stringify(resp.abi, null, 4) : '' };
    });
}
function registerContracts(sessionToken, payload) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data, error } = yield (0, request_1.post)((0, routes_1.buildUrl)(routes_1.routes.REGISTER_CONTRACTS), payload, formatAuthHeader(sessionToken));
        return error ? { error } : data;
    });
}
function getContractRegistrationJob(sessionToken, uid) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data, error } = yield (0, request_1.get)((0, routes_1.buildUrl)(routes_1.routes.GET_CONTRACT_REGISTRATION_JOB), { uid }, formatAuthHeader(sessionToken));
        return error ? { error } : data;
    });
}
function createContractGroup(sessionToken, nsp, name, isFactoryGroup, abi) {
    return __awaiter(this, void 0, void 0, function* () {
        const { error } = yield (0, request_1.post)((0, routes_1.buildUrl)(routes_1.routes.CREATE_CONTRACT_GROUP), {
            nsp,
            name,
            isFactoryGroup,
            abi,
        }, formatAuthHeader(sessionToken));
        return { error };
    });
}
function getContractGroup(group) {
    return __awaiter(this, void 0, void 0, function* () {
        const { error, data } = yield (0, request_1.get)((0, routes_1.buildUrl)(routes_1.routes.GET_CONTRACT_GROUP), {
            group,
        });
        return error ? { error } : { instances: (data === null || data === void 0 ? void 0 : data.instances) || {} };
    });
}
function getContractGroupEvents(group) {
    return __awaiter(this, void 0, void 0, function* () {
        const { error, data } = yield (0, request_1.get)((0, routes_1.buildUrl)(routes_1.routes.GET_CONTRACT_GROUP_EVENTS), {
            group,
        });
        return error ? { error } : { events: (data === null || data === void 0 ? void 0 : data.events) || [] };
    });
}
function resolveEventVersionCursors(givenName) {
    return __awaiter(this, void 0, void 0, function* () {
        const { error, data } = yield (0, request_1.post)((0, routes_1.buildUrl)(routes_1.routes.RESOLVE_EVENT_VERSION_CURSORS), {
            givenName,
        });
        return error ? { error } : { cursors: (data === null || data === void 0 ? void 0 : data.cursors) || [], latestEvent: data === null || data === void 0 ? void 0 : data.latestEvent };
    });
}
function getEventVersionDataAfter(cursors) {
    return __awaiter(this, void 0, void 0, function* () {
        const { error, data } = yield (0, request_1.post)((0, routes_1.buildUrl)(routes_1.routes.GET_EVENT_VERSION_DATA_AFTER), { cursors });
        return error ? { error } : { events: (data === null || data === void 0 ? void 0 : data.events) || {} };
    });
}
function getLiveObjectVersion(id) {
    return __awaiter(this, void 0, void 0, function* () {
        const { error, data } = yield (0, request_1.get)((0, routes_1.buildUrl)(routes_1.routes.GET_LIVE_OBJECT_VERSION), { id });
        return error ? { error } : { lov: data };
    });
}
function publishLiveObjectVersion(nsp, name, version, folder, sessionToken) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data, error } = yield (0, request_1.post)((0, routes_1.buildUrl)(routes_1.routes.PUBLISH_LIVE_OBJECT_VERSION), {
            nsp,
            name,
            version,
            folder,
        }, formatAuthHeader(sessionToken));
        return error ? { error } : data;
    });
}
function getPublishLiveObjectVersionJob(sessionToken, uid) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data, error } = yield (0, request_1.get)((0, routes_1.buildUrl)(routes_1.routes.GET_PUBLISH_LIVE_OBJECT_VERSION_JOB), { uid }, formatAuthHeader(sessionToken));
        return error ? { error } : data;
    });
}
exports.client = {
    login,
    getProject,
    logs,
    getAbi,
    registerContracts,
    getContractRegistrationJob,
    createContractGroup,
    getContractGroup,
    getContractGroupEvents,
    resolveEventVersionCursors,
    getEventVersionDataAfter,
    getLiveObjectVersion,
    publishLiveObjectVersion,
    getPublishLiveObjectVersionJob,
};
//# sourceMappingURL=client.js.map