"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const auth_1 = require("../../utils/auth");
const logger_1 = require("../../logger");
const msg_1 = __importDefault(require("../../utils/msg"));
const client_1 = require("../../api/client");
const validators_1 = require("../../utils/validators");
const abi_1 = require("../../utils/abi");
const prompt_1 = require("../../utils/prompt");
const CMD = 'group';
function addCreateGroupCmd(cmd) {
    cmd.command(CMD)
        .description('Create a new Contract Group')
        .argument('[group]', 'Name of the contract group in "nsp.ContractName" format', null)
        .option('--abi <abi>', `Path to the group's ABI`, null)
        .option('--factory-group', `Whether this group holds factory-produced contracts`)
        .action(createGroup);
}
/**
 * Create a new contract group.
 */
function createGroup(group, opts) {
    return __awaiter(this, void 0, void 0, function* () {
        // Get authed user's session token (if any).
        const { token: sessionToken, error } = (0, auth_1.getSessionToken)();
        if (error) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!sessionToken) {
            (0, logger_1.log)(msg_1.default.AUTH_REQUIRED_MESSAGE);
            return;
        }
        // Prompt user for inputs if not given directly.
        const promptResp = yield (0, prompt_1.promptCreateContractGroupDetails)(group, opts.abi, opts.factoryGroup);
        // Validate contract group structure (e.g. "nsp.ContractName")
        if (!(0, validators_1.isValidContractGroup)(promptResp.group)) {
            (0, logger_1.logWarning)(`Invalid contract group "${promptResp.group}. Make sure it's in "nsp.ContractName" format.`);
            return;
        }
        const [nsp, contractName] = promptResp.group.split('.');
        // Resolve, parse, and validate ABI.
        const { abi, isValid: isAbiValid } = (0, abi_1.resolveAbi)(promptResp.abi);
        if (!isAbiValid)
            return;
        // Create empty contract group.
        const { error: createError } = yield client_1.client.createContractGroup(sessionToken, nsp, contractName, promptResp.isFactoryGroup, abi);
        if (createError) {
            (0, logger_1.logFailure)(`Creating group failed: ${createError}`);
            return;
        }
        (0, logger_1.logSuccess)(`Successfully created contract group "${promptResp.group}".`);
    });
}
exports.default = addCreateGroupCmd;
//# sourceMappingURL=group.js.map