"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../logger");
const msg_1 = __importDefault(require("../../utils/msg"));
const db_1 = require("../../db");
const db_2 = require("../../db");
const CMD = 'init';
function addInitCmd(cmd) {
    cmd.command(CMD)
        .description('Initialize a Postgres database to use Spec')
        .option('-n, --name <type>', 'Database name')
        .option('--url <type>', 'Database URL')
        .action(initDB);
}
/**
 * Initialize a Postgres database to use Spec.
 */
function initDB(options) {
    return __awaiter(this, void 0, void 0, function* () {
        // Ensure psql is installed.
        if (!(0, db_1.psqlInstalled)()) {
            (0, logger_1.logWarning)(msg_1.default.INSTALL_PSQL);
            return;
        }
        const { name, url } = options;
        if (!name && !url) {
            (0, logger_1.logWarning)(`Database not specified.\nEither use --name <dbname> or --url <dburl> to specify which database to initialize.`);
            return;
        }
        // Initialize database with Spec user/schema.
        const { alreadyInitialized, error: initDBError } = yield (0, db_2.initDatabase)(name, url);
        if (initDBError) {
            (0, logger_1.logFailure)(`Error initializing database: ${initDBError}`);
            return;
        }
        if (alreadyInitialized) {
            (0, logger_1.log)(`Database already initialized for Spec.`);
            return;
        }
        (0, logger_1.logSuccess)(`Database ready to be used with Spec.`);
    });
}
exports.default = addInitCmd;
//# sourceMappingURL=init.js.map