"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../logger");
const global_1 = require("../../config/global");
const msg_1 = __importDefault(require("../../utils/msg"));
const path_1 = __importDefault(require("path"));
const file_1 = require("../../utils/file");
const constants_1 = __importDefault(require("../../constants"));
const graphql_1 = require("../../addons/graphql");
const templates_1 = require("../../templates");
const CMD = 'graphql';
function addEnableGraphQLCmd(cmd) {
    cmd.command(CMD)
        .description('Enable the GraphQL add-on for your Spec project')
        .action(enableGraphQL);
}
/**
 * Enable the GraphQL add-on for your Spec project.
 */
function enableGraphQL() {
    return __awaiter(this, void 0, void 0, function* () {
        // Get the current project id.
        const { data: projectId, error } = (0, global_1.getCurrentProjectId)();
        if (error) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!projectId) {
            (0, logger_1.logWarning)(msg_1.default.CHOOSE_PROJECT_MESSAGE);
            return;
        }
        // Get the current project env (local, staging, prod, etc).
        const { data: projectEnv, error: getEnvError } = (0, global_1.getCurrentProjectEnv)();
        if (getEnvError) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!projectEnv) {
            (0, logger_1.logWarning)(msg_1.default.NO_CURRENT_ENV_MESSAGE);
            return;
        }
        // Get the location of the project (/path/to/project)
        const { data: projectInfo, error: getProjectError } = (0, global_1.getProjectInfo)(projectId);
        if (getProjectError) {
            (0, logger_1.logFailure)(error);
            return;
        }
        const { location: projectDirPath } = projectInfo || {};
        if (!projectDirPath) {
            (0, logger_1.logWarning)(msg_1.default.NO_PROJECT_LOCATION);
            return;
        }
        const specConfigDir = path_1.default.join(projectDirPath, constants_1.default.SPEC_CONFIG_DIR_NAME);
        if (!(0, file_1.fileExists)(specConfigDir)) {
            (0, logger_1.logWarning)(`Spec config directory doesn't exist at ${specConfigDir}.`);
            return;
        }
        (0, graphql_1.installPostgraphile)();
        (0, templates_1.createPostgraphileTemplate)(specConfigDir);
        (0, logger_1.logSuccess)('Successfully enabled GraphQL.');
    });
}
exports.default = addEnableGraphQLCmd;
//# sourceMappingURL=graphql.js.map