"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../logger");
const client_1 = require("../../api/client");
const validators_1 = require("../../utils/validators");
const CMD = 'abi';
function addGetAbiCmd(cmd) {
    cmd.command(CMD)
        .description('Get the ABI for a Contract Group')
        .argument('group', 'Contract group to get the ABI for')
        .action(getAbi);
}
/**
 * Get the ABI for a Contract Group.
 */
function getAbi(group) {
    return __awaiter(this, void 0, void 0, function* () {
        // Validate contract group structure (e.g. "nsp.ContractName")
        if (!(0, validators_1.isValidContractGroup)(group)) {
            (0, logger_1.logWarning)(`Invalid contract group "${group}. Make sure it's in "nsp.ContractName" format.`);
            return;
        }
        const { error, abi } = yield client_1.client.getAbi(group);
        if (error) {
            (0, logger_1.logFailure)(`ABI retreival failed: ${error}`);
            return;
        }
        (0, logger_1.log)(abi);
    });
}
exports.default = addGetAbiCmd;
//# sourceMappingURL=abi.js.map