"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../logger");
const chalk_1 = __importDefault(require("chalk"));
const client_1 = require("../../api/client");
const validators_1 = require("../../utils/validators");
const CMD = 'events';
function addGetEventsCmd(cmd) {
    cmd.command(CMD)
        .description('List the events in a Contract Group')
        .argument('group', 'Contract group to get events for')
        .action(getContractGroupEvents);
}
/**
 * List the events in a Contract Group.
 */
function getContractGroupEvents(group) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!(0, validators_1.isValidContractGroup)(group)) {
            (0, logger_1.logWarning)(`Invalid contract group "${group}". Make sure it's in "nsp.GroupName" format.`);
            return;
        }
        const { error, events } = yield client_1.client.getContractGroupEvents(group);
        if (error) {
            (0, logger_1.logFailure)(`Contract group event retreival failed: ${error}`);
            return;
        }
        if (!events.length) {
            (0, logger_1.logWarning)(`No events found for group "${group}"`);
            return;
        }
        (0, logger_1.log)(formatContractGroupEvents(events));
    });
}
function formatContractGroupEvents(events) {
    let allEvents = [];
    for (const event of events) {
        const eventName = `${event.name}`;
        const eventVersion = chalk_1.default.gray(` | ${event.version}`);
        allEvents.push(eventName + eventVersion);
    }
    const maxLen = Math.max(...allEvents.map((line) => line.split(' |')[0].length));
    allEvents = allEvents.map((line) => {
        let [firstPart, secondPart] = line.split(' |');
        return firstPart.padEnd(maxLen, ' ') + ' |' + secondPart;
    });
    return allEvents.join('\n');
}
exports.default = addGetEventsCmd;
//# sourceMappingURL=events.js.map