"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../logger");
const client_1 = require("../../api/client");
const validators_1 = require("../../utils/validators");
const formatters_1 = require("../../utils/formatters");
const chains_1 = require("../../utils/chains");
const chalk_1 = __importDefault(require("chalk"));
const CMD = 'group';
function addGetGroupCmd(cmd) {
    cmd.command(CMD)
        .description('List the addresses in a Contract Group')
        .argument('group', 'Contract group to get the ABI for')
        .action(getGroup);
}
/**
 * List the addresses in a Contract Group.
 */
function getGroup(group) {
    return __awaiter(this, void 0, void 0, function* () {
        // Validate contract group structure (e.g. "nsp.ContractName")
        if (!(0, validators_1.isValidContractGroup)(group)) {
            (0, logger_1.logWarning)(`Invalid contract group "${group}". Make sure it's in "nsp.GroupName" format.`);
            return;
        }
        // Get all contract addresses, across all chains, in this contract group.
        const { error: getGroupError, instances } = yield client_1.client.getContractGroup(group);
        if (getGroupError) {
            (0, logger_1.logFailure)(`Contract group retreival failed: ${getGroupError}`);
            return;
        }
        if (!Object.keys(instances).length) {
            (0, logger_1.logWarning)(`No contracts found in group "${group}"`);
            return;
        }
        // Show the addresses grouped by chain.
        (0, logger_1.log)(formatInstances(instances));
    });
}
function formatInstances(instances) {
    const allGroups = [];
    for (const chainId in instances) {
        const groupTitle = `${chalk_1.default.cyanBright((0, formatters_1.capitalize)(chains_1.chainNameForId[chainId]))} ${chalk_1.default.gray('| ' + chainId)}`;
        const addresses = Object.values(instances[chainId]).map((i) => i.address);
        const groupAddresses = addresses.map((a) => `    ${a}`).join('\n');
        const group = `${groupTitle}\n\n${groupAddresses}\n`;
        allGroups.push(group);
    }
    return allGroups.join('\n');
}
exports.default = addGetGroupCmd;
//# sourceMappingURL=group.js.map