"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("../config");
const logger_1 = require("../logger");
const file_1 = require("../utils/file");
const connect_1 = require("../config/connect");
const path_1 = __importDefault(require("path"));
const constants_1 = __importDefault(require("../constants"));
const fs_1 = __importDefault(require("fs"));
const project_1 = require("../config/project");
const CMD = 'init';
function addInitCmd(program) {
    program.command(CMD).description('Initialize a new Spec project').action(init);
}
/**
 * Initialize a new Spec project locally.
 */
function init() {
    return __awaiter(this, void 0, void 0, function* () {
        const connectConfigExists = (0, connect_1.localConnectConfigFileExists)();
        const projectConfigExists = (0, project_1.localProjectConfigFileExists)();
        if (connectConfigExists && projectConfigExists) {
            (0, logger_1.log)('Project already initialized.');
            return;
        }
        // Create new Spec config directory + project/connection config files.
        (0, config_1.createNewSpecConfig)();
        // Add connect.toml to .gitignore if file exists.
        const gitignorePath = path_1.default.join(process.cwd(), '.gitignore');
        if ((0, file_1.fileExists)(gitignorePath)) {
            const lines = (0, file_1.getFileLines)(gitignorePath);
            const connectLine = `${path_1.default.join(constants_1.default.SPEC_CONFIG_DIR_NAME, constants_1.default.CONNECTION_CONFIG_FILE_NAME)}`;
            const alreadyIgnored = lines.find((line) => line.includes(connectLine));
            alreadyIgnored || fs_1.default.appendFileSync(gitignorePath, `\n${connectLine}`);
        }
        const completelyNew = !connectConfigExists && !projectConfigExists;
        (0, logger_1.logSuccess)(completelyNew ? 'Inititalized new Spec project.' : 'Reinitialized Spec project.');
    });
}
exports.default = addInitCmd;
//# sourceMappingURL=init.js.map