"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.linkProject = void 0;
const formatters_1 = require("../../utils/formatters");
const logger_1 = require("../../logger");
const project_1 = require("../use/project");
const file_1 = require("../../utils/file");
const global_1 = require("../../config/global");
const path_1 = __importDefault(require("path"));
const constants_1 = __importDefault(require("../../constants"));
const config_1 = require("../../config");
const fs_1 = __importDefault(require("fs"));
const CMD = 'project';
function addProjectCmd(cmd) {
    cmd.command(CMD)
        .description('Set the local path for a project')
        .argument('project', 'The project to link in <namespace>/<project> format')
        .argument('directory', 'Local path to the project (should contain a ".spec/" folder)')
        .action(linkProject);
}
/**
 * Set the local path for a project.
 */
function linkProject(projectPath, localPath, logResult = true) {
    return __awaiter(this, void 0, void 0, function* () {
        // Split input into namespace/project.
        const pathComps = (0, formatters_1.repoPathToComponents)(projectPath);
        if (!pathComps) {
            (0, logger_1.logWarning)('Please specify the project in <namespace>/<project> format.');
            return false;
        }
        const [nsp, projectName] = pathComps;
        // Ensure specified location actually exists.
        const location = path_1.default.resolve(localPath);
        if (!(0, file_1.fileExists)(location)) {
            (0, logger_1.logWarning)(`Local path not found: ${location}`);
            return false;
        }
        // Pull the project and set it as the current one.
        const useProjectResp = yield (0, project_1.useProject)(projectPath, false);
        if (!useProjectResp)
            return false;
        const { id: projectId } = useProjectResp;
        // (If needed) create new Spec config directory + project/connection config files.
        const specConfigDir = path_1.default.join(location, constants_1.default.SPEC_CONFIG_DIR_NAME);
        (0, config_1.createNewSpecConfig)(specConfigDir);
        // Add connect.toml to .gitignore if file exists.
        const gitignorePath = path_1.default.join(location, '.gitignore');
        if ((0, file_1.fileExists)(gitignorePath)) {
            const lines = (0, file_1.getFileLines)(gitignorePath);
            const connectLine = `${path_1.default.join(constants_1.default.SPEC_CONFIG_DIR_NAME, constants_1.default.CONNECTION_CONFIG_FILE_NAME)}`;
            const alreadyIgnored = lines.find((line) => line.includes(connectLine));
            alreadyIgnored || fs_1.default.appendFileSync(gitignorePath, `\n${connectLine}`);
        }
        // Set the location of project in global config.
        (0, global_1.setProjectLocation)(nsp, projectName, projectId, location);
        logResult && (0, logger_1.logSuccess)(`Set location of project "${projectPath}" to "${location}"`);
        return true;
    });
}
exports.linkProject = linkProject;
exports.default = addProjectCmd;
//# sourceMappingURL=project.js.map