"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../logger");
const client_1 = require("../api/client");
const prompt_1 = require("../utils/prompt");
const auth_1 = require("../utils/auth");
const CMD = 'login';
function addLoginCmd(program) {
    program.command(CMD).description('Log in to your Spec account').action(login);
}
/**
 * Login to Spec with email/password.
 */
function login() {
    return __awaiter(this, void 0, void 0, function* () {
        // Prompt user for email/password.
        const { email, password } = yield (0, prompt_1.promptEmailPassword)();
        // Exchange email/password for a new session token.
        const { message, sessionToken, error } = yield client_1.client.login(email, password);
        if (error) {
            (0, logger_1.logFailure)(`Login failed: ${error}`);
            return;
        }
        if (!sessionToken) {
            (0, logger_1.logFailure)('Login failed: No session found in response.');
            return;
        }
        // Save session token to .netrc
        const { error: saveError } = (0, auth_1.persistSession)(email, sessionToken);
        if (saveError) {
            (0, logger_1.logFailure)(`Login failed: ${saveError}.`);
            return;
        }
        (0, logger_1.logSuccess)(message);
    });
}
exports.default = addLoginCmd;
//# sourceMappingURL=login.js.map