"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __asyncValues = (this && this.__asyncValues) || function (o) {
    if (!Symbol.asyncIterator) throw new TypeError("Symbol.asyncIterator is not defined.");
    var m = o[Symbol.asyncIterator], i;
    return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
    function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
    function settle(resolve, reject, d, v) { Promise.resolve(v).then(function(v) { resolve({ value: v, done: d }); }, reject); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../logger");
const client_1 = require("../api/client");
const msg_1 = __importDefault(require("../utils/msg"));
const types_1 = require("../types");
const global_1 = require("../config/global");
const auth_1 = require("../utils/auth");
const json_1 = require("@streamparser/json");
const client_2 = require("../utils/client");
const chalk_1 = __importDefault(require("chalk"));
const process_1 = require("process");
const constants_1 = __importDefault(require("../constants"));
const CMD = 'logs';
function addLogsCmd(program) {
    program
        .command(CMD)
        .description('Tail the logs of your current Spec project')
        .option('--local', 'Display logs for the locally running Spec instance')
        .option('--env <type>', 'Filter logs by Spec environment')
        .option('--tail <number>', 'Lines of historical logs to show', constants_1.default.DEFAULT_LOG_TAIL_SIZE)
        .action(logs);
}
/**
 * Tail the logs for the currently linked Spec project.
 */
function logs(options) {
    return __awaiter(this, void 0, void 0, function* () {
        // Get authed user's session token (if any).
        const { token, error } = (0, auth_1.getSessionToken)();
        if (error) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!token) {
            (0, logger_1.log)(msg_1.default.AUTH_REQUIRED_MESSAGE);
            return;
        }
        // Get current project id.
        const { data: projectId, error: currProjectIdError } = (0, global_1.getCurrentProjectId)();
        if (currProjectIdError) {
            (0, logger_1.logFailure)(currProjectIdError);
            return;
        }
        if (!projectId) {
            (0, logger_1.log)(msg_1.default.CHOOSE_PROJECT_MESSAGE);
            return;
        }
        // Get log tail size.
        const tail = parseInt(options.tail, 10);
        if (isNaN(tail) || tail < 0) {
            (0, logger_1.logWarning)(`--tail must be a number >= 0`);
            return;
        }
        // Stream logs from local spec instance if --local option provided.
        if (!!options.local || options.env === 'local') {
            const { error: logsError } = yield (0, client_2.followLocalLogs)(projectId, tail);
            if (logsError) {
                (0, logger_1.logFailure)(logsError);
            }
            return;
        }
        // Fetch log stream.
        const { data: body, error: apiError } = yield client_1.client.logs(projectId, token, tail, options.env);
        if (apiError) {
            (0, logger_1.logFailure)(`Error fetching project logs: ${apiError}`);
            return;
        }
        // Format & print logs as they come.
        try {
            yield streamLogs(body);
        }
        catch (err) {
            (0, logger_1.logFailure)(`Error iterating log stream: ${(err === null || err === void 0 ? void 0 : err.message) || err}`);
            (0, process_1.exit)(1);
        }
    });
}
function streamLogs(body) {
    var body_1, body_1_1;
    var e_1, _a;
    return __awaiter(this, void 0, void 0, function* () {
        const jsonParser = new json_1.JSONParser({
            stringBufferSize: undefined,
            paths: ['$.*'],
            keepStack: false,
        });
        jsonParser.onValue = (obj) => {
            if (!obj || obj.ping)
                return;
            const data = obj;
            printLog(data);
        };
        try {
            for (body_1 = __asyncValues(body); body_1_1 = yield body_1.next(), !body_1_1.done;) {
                const chunk = body_1_1.value;
                jsonParser.write(chunk);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (body_1_1 && !body_1_1.done && (_a = body_1.return)) yield _a.call(body_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
    });
}
function printLog(data) {
    const timestamp = chalk_1.default.gray(data.timestamp);
    let level;
    switch (data.level) {
        case types_1.LogLevel.Error:
            level = chalk_1.default.redBright(data.level.toUpperCase());
            break;
        case types_1.LogLevel.Warn:
            level = chalk_1.default.yellowBright(data.level.toUpperCase());
            break;
        default:
            level = chalk_1.default.gray(data.level.toUpperCase());
    }
    const leftSplit = chalk_1.default.gray('|');
    const rightSplit = data.level === types_1.LogLevel.Error ? chalk_1.default.redBright('->') : chalk_1.default.gray('|');
    const message = (data.message || '')
        .split('\n')
        .map((line, i) => {
        let levelText = level;
        if (i > 0 && data.level !== types_1.LogLevel.Info) {
            const ellipsis = ' ...';
            switch (data.level) {
                case types_1.LogLevel.Error:
                    levelText = chalk_1.default.redBright(ellipsis);
                    break;
                case types_1.LogLevel.Warn:
                    levelText = chalk_1.default.yellowBright(ellipsis);
                    break;
            }
        }
        const prefix = `${timestamp} ${leftSplit} ${levelText} ${rightSplit}`;
        return `${prefix} ${line}`;
    })
        .join('\n');
    (0, logger_1.log)(message);
}
exports.default = addLogsCmd;
//# sourceMappingURL=logs.js.map