"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../logger");
const path_1 = __importDefault(require("path"));
const constants_1 = __importDefault(require("../../constants"));
const migrations_1 = require("../../config/migrations");
const global_1 = require("../../config/global");
const msg_1 = __importDefault(require("../../utils/msg"));
const file_1 = require("../../utils/file");
const CMD = 'migration';
function addMigrationCmd(cmd) {
    cmd.command(CMD)
        .description('Create a new migration for the current project')
        .argument('name', 'Name of the migration')
        .action(newEmptyMigration);
}
/**
 * Create a new migration (up/down) for your current Spec project.
 */
function newEmptyMigration(name) {
    return __awaiter(this, void 0, void 0, function* () {
        // Get the current project id.
        const { data: projectId, error } = (0, global_1.getCurrentProjectId)();
        if (error) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!projectId) {
            (0, logger_1.logWarning)(msg_1.default.CHOOSE_PROJECT_MESSAGE);
            return;
        }
        // Get the location of the project (/path/to/project)
        const { data: projectInfo, error: getProjectError } = (0, global_1.getProjectInfo)(projectId);
        if (getProjectError) {
            (0, logger_1.logFailure)(error);
            return;
        }
        const { location: projectDirPath } = projectInfo || {};
        if (!projectDirPath) {
            (0, logger_1.logWarning)(msg_1.default.NO_PROJECT_LOCATION);
            return;
        }
        const specConfigDir = path_1.default.join(projectDirPath, constants_1.default.SPEC_CONFIG_DIR_NAME);
        if (!(0, file_1.fileExists)(specConfigDir)) {
            (0, logger_1.logWarning)(`Spec config directory doesn't exist at ${specConfigDir}.`);
            return;
        }
        // Create new empty migration object with a version attached to the given name.
        const migration = (0, migrations_1.newMigration)(name);
        // Create/save empty up.sql and down.sql files inside the new migration version dir.
        const { versionDir, error: creationError } = (0, migrations_1.saveMigration)(projectDirPath, migration);
        if (creationError) {
            (0, logger_1.logFailure)(creationError);
            return;
        }
        (0, logger_1.logSuccess)(`New empty migration at "${versionDir}"`);
    });
}
exports.default = addMigrationCmd;
//# sourceMappingURL=migration.js.map