"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../logger");
const templates_1 = require("../../templates");
const prompt_1 = require("../../utils/prompt");
const CMD = 'table';
function addTableCommand(cmd) {
    cmd.command(CMD)
        .description('Create a new custom Live Table')
        .argument('[fullName]', 'The full name of the Live Table in "nsp.Name" format', null)
        .action(newTable);
}
/**
 * Create a new Live Table template.
 */
function newTable(fullName) {
    return __awaiter(this, void 0, void 0, function* () {
        let namespace = '';
        let name = '';
        if (fullName) {
            const splitFullName = fullName.split('.');
            if (splitFullName.length !== 2) {
                (0, logger_1.logWarning)('Invalid full name for object: Must be in "nsp.Name" format.');
                return;
            }
            ;
            [namespace, name] = splitFullName;
        }
        const promptResp = yield (0, prompt_1.promptNewLiveObjectDetails)(namespace, name);
        ({ namespace, name } = promptResp);
        const { displayName, description } = promptResp;
        if (!namespace || !name) {
            (0, logger_1.logWarning)('Both "namespace" and "name" are required.');
            return;
        }
        const { liveObjectId, success } = (0, templates_1.createLiveObjectTemplate)(namespace, name, displayName, description);
        if (!success)
            return;
        (0, logger_1.logSuccess)(`Created template for live object "${liveObjectId}" in folder "./${name}"`);
    });
}
exports.default = addTableCommand;
//# sourceMappingURL=table.js.map