"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.quickstart = void 0;
const path_1 = __importDefault(require("path"));
const logger_1 = require("../logger");
const connect_1 = require("../config/connect");
const db_1 = require("../db");
const constants_1 = __importDefault(require("../constants"));
const file_1 = require("../utils/file");
const project_1 = require("./link/project");
const process_1 = __importDefault(require("process"));
const CMD = 'quickstart';
function addQuickstartCmd(program) {
    program
        .command(CMD)
        .description('Quickstart the setup for a Spec project')
        .argument('project', 'The project to quickstart in <namespace>/<project> format')
        .action(quickstart);
}
/**
 * Speedrun the project setup process.
 */
function quickstart(project) {
    return __awaiter(this, void 0, void 0, function* () {
        // Link the given project to the cwd and initialize this folder as a Spec project.
        const linkedProject = yield (0, project_1.linkProject)(project, '.', false);
        if (!linkedProject) {
            (0, logger_1.logWarning)(`Failed to link project ${project} to the current working directory.`);
            return;
        }
        // Get refs to the spec config dir.
        const projectDirPath = process_1.default.cwd();
        const specConfigDir = path_1.default.join(projectDirPath, constants_1.default.SPEC_CONFIG_DIR_NAME);
        if (!(0, file_1.fileExists)(specConfigDir)) {
            (0, logger_1.logWarning)(`Spec config directory doesn't exist at ${specConfigDir}.`);
            return;
        }
        // Get the current "local" database environment info from connect.toml.
        const projectEnv = 'local';
        const { data: dbConfig, error: getDBConfigError } = (0, connect_1.getDBConfig)(projectDirPath, projectEnv);
        if (getDBConfigError) {
            (0, logger_1.logFailure)(getDBConfigError);
            return;
        }
        if (!dbConfig) {
            (0, logger_1.logWarning)(`No environment named "${projectEnv}" inside ${constants_1.default.CONNECTION_CONFIG_FILE_NAME}.`);
            return;
        }
        // If database name already specified, stop here.
        if (dbConfig.name) {
            (0, logger_1.logSuccess)(`Quickstart complete.`);
            return;
        }
        // Upsert the quickstart database.
        const dbName = constants_1.default.QUICKSTART_DB_NAME;
        const { error: dbError } = (0, db_1.upsertDatabase)(dbName);
        if (dbError) {
            (0, logger_1.logFailure)(`Failed to upsert the "${dbName}" local database: ${dbError}`);
            return;
        }
        // Set the quickstart database as the DB name for the local env.
        const { error: fileError } = (0, connect_1.updateDatabaseNameForEnv)(projectDirPath, projectEnv, dbName);
        if (fileError) {
            (0, logger_1.logFailure)(`Failed to update connect.toml: ${fileError}`);
            return;
        }
        (0, logger_1.logSuccess)(`Quickstart complete.`);
    });
}
exports.quickstart = quickstart;
exports.default = addQuickstartCmd;
//# sourceMappingURL=quickstart.js.map