"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../../logger");
const global_1 = require("../../config/global");
const connect_1 = require("../../config/connect");
const msg_1 = __importDefault(require("../../utils/msg"));
const path_1 = __importDefault(require("path"));
const file_1 = require("../../utils/file");
const constants_1 = __importDefault(require("../../constants"));
const graphql_1 = require("../../addons/graphql");
const postgraphilercTemplate_1 = require("../../templates/postgraphilercTemplate");
const formatters_1 = require("../../utils/formatters");
const db_1 = require("../../db");
const graphql_2 = require("../../addons/graphql");
const CMD = 'graphql';
function addRunGraphQLCmd(cmd) {
    cmd.command(CMD)
        .description('Start a local GraphQL API into your Spec database')
        .action(runGraphQL);
}
/**
 * Start a GraphQL API locally with your Spec database.
 */
function runGraphQL() {
    return __awaiter(this, void 0, void 0, function* () {
        // Get the current project id.
        const { data: projectId, error } = (0, global_1.getCurrentProjectId)();
        if (error) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!projectId) {
            (0, logger_1.logWarning)(msg_1.default.CHOOSE_PROJECT_MESSAGE);
            return;
        }
        // Get the current project env (local, staging, prod, etc).
        const { data: projectEnv, error: getEnvError } = (0, global_1.getCurrentProjectEnv)();
        if (getEnvError) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!projectEnv) {
            (0, logger_1.logWarning)(msg_1.default.NO_CURRENT_ENV_MESSAGE);
            return;
        }
        // Get the location of the project (/path/to/project)
        const { data: projectInfo, error: getProjectError } = (0, global_1.getProjectInfo)(projectId);
        if (getProjectError) {
            (0, logger_1.logFailure)(error);
            return;
        }
        const { location: projectDirPath } = projectInfo || {};
        if (!projectDirPath) {
            (0, logger_1.logWarning)(msg_1.default.NO_PROJECT_LOCATION);
            return;
        }
        const specConfigDir = path_1.default.join(projectDirPath, constants_1.default.SPEC_CONFIG_DIR_NAME);
        if (!(0, file_1.fileExists)(specConfigDir)) {
            (0, logger_1.logWarning)(`Spec config directory doesn't exist at ${specConfigDir}.`);
            return;
        }
        // Get DB info from connection config file.
        let { data: dbConfig, error: getDBConfigError } = (0, connect_1.getDBConfig)(projectDirPath, projectEnv);
        if (getDBConfigError) {
            (0, logger_1.logFailure)(getDBConfigError);
            return;
        }
        if (!dbConfig) {
            (0, logger_1.logWarning)(`No environment named "${projectEnv}" inside ${constants_1.default.CONNECTION_CONFIG_FILE_NAME}.`);
            return;
        }
        if (!dbConfig.name) {
            (0, logger_1.logWarning)(`No database "name" specified for the "${projectEnv}" environment in ${constants_1.default.CONNECTION_CONFIG_FILE_NAME}.`);
            return;
        }
        const { data: connParams, error: formatError } = (0, db_1.resolveDBConnectionParams)(dbConfig);
        if (formatError) {
            (0, logger_1.logWarning)(`Invalid database environment "${projectEnv}" — ${formatError}`);
            return false;
        }
        // Ensure database was already initialized for Spec.
        const url = (0, formatters_1.asPostgresUrl)(connParams);
        const { data: alreadyInitializedDb, error: schemaError } = (0, db_1.specSchemaTablesExist)(connParams.name, url);
        if (schemaError) {
            (0, logger_1.logFailure)(schemaError);
            return false;
        }
        if (!alreadyInitializedDb) {
            (0, logger_1.logWarning)(msg_1.default.DB_NOT_INITIALIZED);
            return false;
        }
        if (!(0, graphql_1.isPostgraphileInstalled)()) {
            (0, logger_1.logWarning)(`Postgraphile currently isn't installed...is the GraphQL add-on enabled?\n` +
                `Run "spec enable graphql" and try again.`);
            return;
        }
        if (!(0, postgraphilercTemplate_1.doesPostgraphilercExist)(specConfigDir)) {
            (0, logger_1.logWarning)(`No Postgraphile config was found for the current project...is the GraphQL add-on enabled?\n` +
                `Run "spec enable graphql" and try again.`);
            return;
        }
        (0, graphql_2.startPostgraphile)(specConfigDir, url);
    });
}
exports.default = addRunGraphQLCmd;
//# sourceMappingURL=graphql.js.map