"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const global_1 = require("../../config/global");
const logger_1 = require("../../logger");
const msg_1 = __importDefault(require("../../utils/msg"));
const CMD = 'project';
function addProjectCmd(cmd) {
    cmd.command(CMD).description('Show the current project').action(showProject);
}
/**
 * Show the current project.
 */
function showProject() {
    return __awaiter(this, void 0, void 0, function* () {
        // Get current project id.
        const { data: projectId, error } = (0, global_1.getCurrentProjectId)();
        if (error) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!projectId) {
            (0, logger_1.log)(msg_1.default.NO_CURRENT_PROJECT_MESSAGE);
            return;
        }
        // Get project info from global spec creds file.
        const { data, error: infoError } = (0, global_1.getProjectCreds)(projectId);
        if (infoError) {
            (0, logger_1.logFailure)(infoError);
            return;
        }
        if (!(data === null || data === void 0 ? void 0 : data.path)) {
            (0, logger_1.log)(msg_1.default.NO_CURRENT_PROJECT_MESSAGE);
            return;
        }
        (0, logger_1.logSuccess)(data.path);
    });
}
exports.default = addProjectCmd;
//# sourceMappingURL=project.js.map