"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../logger");
const client_1 = require("../api/client");
const validators_1 = require("../utils/validators");
const time_1 = require("../utils/time");
const events_1 = require("../utils/events");
const CMD = 'tail';
const POLL_INTERVAL = 2000;
function addTailCmd(program) {
    program
        .command(CMD)
        .description('Tail an event stream')
        .argument('event', 'Event to tail')
        .action(tail);
}
/**
 * Tail an event stream on Spec.
 */
function tail(event) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!(0, validators_1.couldBeEventName)(event)) {
            (0, logger_1.logFailure)(`Invalid event name "${event}"`);
            return;
        }
        const { error, cursors, latestEvent } = yield client_1.client.resolveEventVersionCursors(event);
        if (error) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!(cursors === null || cursors === void 0 ? void 0 : cursors.length)) {
            (0, logger_1.logWarning)(`No events found for "${event}"`);
            return;
        }
        latestEvent && (0, logger_1.log)((0, events_1.trimEventData)(latestEvent));
        const nonceForEventName = {};
        for (const entry of cursors) {
            nonceForEventName[entry.name] = entry.nonce;
        }
        while (true) {
            yield (0, time_1.sleep)(POLL_INTERVAL);
            const latestCursors = [];
            for (const [name, nonce] of Object.entries(nonceForEventName)) {
                latestCursors.push({ name, nonce });
            }
            const { error, events: eventsMap } = yield client_1.client.getEventVersionDataAfter(latestCursors);
            if (error) {
                (0, logger_1.logFailure)(error);
                break;
            }
            let eventsToLog = [];
            for (const [name, events] of Object.entries(eventsMap)) {
                if (!(events === null || events === void 0 ? void 0 : events.length))
                    continue;
                eventsToLog.push(...events);
                const latestEvent = events[events.length - 1];
                nonceForEventName[name] = latestEvent.nonce;
            }
            eventsToLog
                .sort(
            // @ts-ignore
            (a, b) => new Date(a.origin.blockTimestamp) - new Date(b.origin.blockTimestamp))
                .forEach((event) => {
                (0, logger_1.log)((0, events_1.trimEventData)(event));
            });
        }
    });
}
exports.default = addTailCmd;
//# sourceMappingURL=tail.js.map