"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEnv = void 0;
const logger_1 = require("../../logger");
const global_1 = require("../../config/global");
const CMD = 'env';
function addEnvCmd(cmd) {
    cmd.command(CMD)
        .description('Set the environment for the current project')
        .argument('env', 'The project environment inside "connect.toml" to set as current.')
        .action(useEnv);
}
/**
 * Set the environment for the current project.
 */
function useEnv(env) {
    return __awaiter(this, void 0, void 0, function* () {
        /*
        TODO:
        ----
        1) Get the current project id from state.toml
        2) Resolve the full project from projects.toml
        3) Use the projects "location" to read connect.toml
        4) Validate the env exists in connect.toml before setting.
        */
        const { error: setEnvError } = (0, global_1.saveState)({ projectEnv: env });
        if (setEnvError) {
            (0, logger_1.logFailure)(setEnvError);
            return;
        }
        (0, logger_1.logSuccess)(`Set current env to "${env}".`);
    });
}
exports.useEnv = useEnv;
exports.default = addEnvCmd;
//# sourceMappingURL=env.js.map