"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useProject = void 0;
const formatters_1 = require("../../utils/formatters");
const logger_1 = require("../../logger");
const client_1 = require("../../api/client");
const msg_1 = __importDefault(require("../../utils/msg"));
const global_1 = require("../../config/global");
const auth_1 = require("../../utils/auth");
const CMD = 'project';
function addProjectCmd(cmd) {
    cmd.command(CMD)
        .description('Set the current project')
        .argument('project', 'Spec project to use in <namespace>/<project> format')
        .action(useProject);
}
/**
 * Set the current project.
 */
function useProject(projectPath, logResult = true) {
    return __awaiter(this, void 0, void 0, function* () {
        // Split input into namespace/project.
        const pathComps = (0, formatters_1.repoPathToComponents)(projectPath);
        if (!pathComps) {
            (0, logger_1.logWarning)('Please specify the project in <namespace>/<project> format.');
            return;
        }
        const [nsp, projectName] = pathComps;
        // Get authed user's session token (if any).
        const { token, error } = (0, auth_1.getSessionToken)();
        if (error) {
            (0, logger_1.logFailure)(error);
            return;
        }
        if (!token) {
            (0, logger_1.logWarning)(msg_1.default.AUTH_REQUIRED_MESSAGE);
            return;
        }
        // Resolve user's project by nsp/name.
        const { id, name, namespace, apiKey, metadata, error: apiError, } = yield client_1.client.getProject(nsp, projectName, token);
        if (apiError) {
            (0, logger_1.logFailure)(`Failed to resolve project ${projectPath}: ${apiError}`);
            return;
        }
        if (!id || !name || !namespace || !apiKey) {
            (0, logger_1.logFailure)(`Failed to resolve project with ${projectPath}.\n
            Couldn't resolve all necessary project attributes:\n
            id=${id}\n
            name=${name}\n 
            namespace=${namespace}\n
            apiKey=${apiKey}`);
            return;
        }
        // Save project id and api key to global creds file.
        const { error: saveCredsError } = (0, global_1.saveProjectCreds)(namespace, name, id, apiKey);
        if (saveCredsError) {
            (0, logger_1.logFailure)(saveCredsError);
            return;
        }
        // Set current project id in global state.
        const { error: setProjectIdError } = (0, global_1.saveState)({
            projectId: id,
            projectEnv: global_1.DEFAULT_PROJECT_ENV,
        });
        if (setProjectIdError) {
            (0, logger_1.logFailure)(setProjectIdError);
            return;
        }
        logResult && (0, logger_1.logSuccess)(`Switched to project: ${namespace}/${name}`);
        return { id, metadata };
    });
}
exports.useProject = useProject;
exports.default = addProjectCmd;
//# sourceMappingURL=project.js.map