"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateDatabaseNameForEnv = exports.getDBConfig = exports.localConnectConfigFileExists = exports.createSpecConnectionConfigFile = void 0;
const file_1 = require("../utils/file");
const constants_1 = __importDefault(require("../constants"));
const j_toml_1 = __importDefault(require("@ltd/j-toml"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const db_1 = require("../db");
const initialTemplate = (user = '') => `# Local database
[local]
name = ''
port = 5432
host = 'localhost'
user = '${user}'
password = ''`;
const createSpecConnectionConfigFile = (specConfigDir) => {
    let { data: user, error } = (0, db_1.getCurrentDbUser)();
    if (error || !user) {
        user = '';
    }
    let contents = initialTemplate(user);
    const filePath = path_1.default.join(specConfigDir || constants_1.default.SPEC_CONFIG_DIR, constants_1.default.CONNECTION_CONFIG_FILE_NAME);
    (0, file_1.fileExists)(filePath) || (0, file_1.createFileWithContents)(filePath, contents);
};
exports.createSpecConnectionConfigFile = createSpecConnectionConfigFile;
const localConnectConfigFileExists = () => (0, file_1.fileExists)(constants_1.default.CONNECTION_CONFIG_PATH);
exports.localConnectConfigFileExists = localConnectConfigFileExists;
function getDBConfig(projectDirPath, projectEnv) {
    const connectFilePath = path_1.default.join(projectDirPath, constants_1.default.SPEC_CONFIG_DIR_NAME, constants_1.default.CONNECTION_CONFIG_FILE_NAME);
    // Ensure connection config file exists.
    if (!(0, file_1.fileExists)(connectFilePath)) {
        return { error: null };
    }
    // Return config for given environment.
    try {
        const data = j_toml_1.default.parse(fs_1.default.readFileSync(connectFilePath, 'utf-8')) || {};
        return { data: data[projectEnv] || null };
    }
    catch (error) {
        return { error };
    }
}
exports.getDBConfig = getDBConfig;
function updateDatabaseNameForEnv(projectDirPath, env, dbName) {
    const connectFilePath = path_1.default.join(projectDirPath, constants_1.default.SPEC_CONFIG_DIR_NAME, constants_1.default.CONNECTION_CONFIG_FILE_NAME);
    // Ensure connection config file exists.
    if (!(0, file_1.fileExists)(connectFilePath)) {
        return { error: `No file found at ${connectFilePath}` };
    }
    // Get existing config.
    let config;
    try {
        config = j_toml_1.default.parse(fs_1.default.readFileSync(connectFilePath, 'utf-8')) || {};
    }
    catch (error) {
        return { error };
    }
    if (!config[env]) {
        return { error: `No environment named ${env} inside connect.toml` };
    }
    config[env].name = dbName;
    return (0, file_1.saveTomlConfigFile)(connectFilePath, config);
}
exports.updateDatabaseNameForEnv = updateDatabaseNameForEnv;
//# sourceMappingURL=connect.js.map