"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveProjectComposeEnvs = exports.saveGlobalProjectsFile = exports.readGlobalProjectsFile = exports.saveGlobalStateFile = exports.readGlobalStateFile = exports.saveGlobalCredsFile = exports.readGlobalCredsFile = exports.upsertSpecGlobalComposeDir = exports.upsertSpecGlobalDir = exports.setProjectLocation = exports.getProjectInfo = exports.saveProjectInfo = exports.saveState = exports.getCurrentProjectEnv = exports.getCurrentProjectId = exports.getProjectCreds = exports.saveProjectCreds = exports.DEFAULT_PROJECT_ENV = void 0;
const file_1 = require("../utils/file");
const j_toml_1 = require("@ltd/j-toml");
const constants_1 = __importDefault(require("../constants"));
const formatters_1 = require("../utils/formatters");
const path_1 = __importDefault(require("path"));
exports.DEFAULT_PROJECT_ENV = 'local';
function saveProjectCreds(nsp, name, id, apiKey) {
    // Ensure spec global config directory exists.
    upsertSpecGlobalDir();
    // Get current global creds.
    const { data, error } = readGlobalCredsFile();
    if (error)
        return { error };
    // Upsert project section within file.
    const creds = data || {};
    const projectPath = [nsp, name].join('/');
    creds[projectPath] = creds[projectPath] || (0, j_toml_1.Section)({});
    creds[projectPath].id = id;
    creds[projectPath].apiKey = apiKey;
    return saveGlobalCredsFile(creds);
}
exports.saveProjectCreds = saveProjectCreds;
function getProjectCreds(projectId) {
    const { data, error } = readGlobalCredsFile();
    if (error)
        return { error };
    const creds = (0, formatters_1.toMap)(data || {});
    for (const key in creds) {
        const projectCreds = creds[key];
        if (projectCreds.id === projectId) {
            return { data: Object.assign(Object.assign({}, projectCreds), { path: key }) };
        }
    }
    return { data: null };
}
exports.getProjectCreds = getProjectCreds;
function getCurrentProjectId() {
    const { data, error } = readGlobalStateFile();
    if (error)
        return { error };
    return { data: (data === null || data === void 0 ? void 0 : data.projectId) || null };
}
exports.getCurrentProjectId = getCurrentProjectId;
function getCurrentProjectEnv() {
    const { data, error } = readGlobalStateFile();
    if (error)
        return { error };
    return { data: (data === null || data === void 0 ? void 0 : data.projectEnv) || null };
}
exports.getCurrentProjectEnv = getCurrentProjectEnv;
function saveState(updates) {
    // Ensure spec global config directory exists.
    upsertSpecGlobalDir();
    // Get current global state.
    const { data, error } = readGlobalStateFile();
    if (error)
        return { error };
    // Apply and save updates.
    return saveGlobalStateFile(Object.assign(Object.assign({}, data), updates));
}
exports.saveState = saveState;
function saveProjectInfo(nsp, name, id, updates) {
    // Ensure spec global config directory exists.
    upsertSpecGlobalDir();
    // Get global projects info.
    const { data, error } = readGlobalProjectsFile();
    if (error)
        return { error };
    // Upsert project section within file.
    const projects = data || {};
    const projectPath = [nsp, name].join('/');
    projects[projectPath] = projects[projectPath] || (0, j_toml_1.Section)({});
    projects[projectPath].id = id;
    for (const key in updates || {}) {
        projects[projectPath][key] = updates[key];
    }
    return saveGlobalProjectsFile(projects);
}
exports.saveProjectInfo = saveProjectInfo;
function getProjectInfo(id) {
    const { data, error } = readGlobalProjectsFile();
    if (error)
        return { error };
    const project = Object.values(data || {}).find((p) => p.id === id);
    if (!project)
        return { data: null };
    return { data: (0, formatters_1.toMap)(project) };
}
exports.getProjectInfo = getProjectInfo;
function setProjectLocation(nsp, name, id, path) {
    saveProjectInfo(nsp, name, id, { location: path });
}
exports.setProjectLocation = setProjectLocation;
function upsertSpecGlobalDir() {
    (0, file_1.fileExists)(constants_1.default.SPEC_GLOBAL_DIR) || (0, file_1.createDir)(constants_1.default.SPEC_GLOBAL_DIR);
}
exports.upsertSpecGlobalDir = upsertSpecGlobalDir;
function upsertSpecGlobalComposeDir() {
    (0, file_1.fileExists)(constants_1.default.SPEC_GLOBAL_COMPOSE_DIR) || (0, file_1.createDir)(constants_1.default.SPEC_GLOBAL_COMPOSE_DIR);
}
exports.upsertSpecGlobalComposeDir = upsertSpecGlobalComposeDir;
function readGlobalCredsFile() {
    return (0, file_1.readTomlConfigFile)(constants_1.default.SPEC_GLOBAL_CREDS_PATH);
}
exports.readGlobalCredsFile = readGlobalCredsFile;
function saveGlobalCredsFile(table) {
    return (0, file_1.saveTomlConfigFile)(constants_1.default.SPEC_GLOBAL_CREDS_PATH, table);
}
exports.saveGlobalCredsFile = saveGlobalCredsFile;
function readGlobalStateFile() {
    return (0, file_1.readTomlConfigFile)(constants_1.default.SPEC_GLOBAL_STATE_PATH);
}
exports.readGlobalStateFile = readGlobalStateFile;
function saveGlobalStateFile(table) {
    return (0, file_1.saveTomlConfigFile)(constants_1.default.SPEC_GLOBAL_STATE_PATH, table);
}
exports.saveGlobalStateFile = saveGlobalStateFile;
function readGlobalProjectsFile() {
    return (0, file_1.readTomlConfigFile)(constants_1.default.SPEC_GLOBAL_PROJECTS_PATH);
}
exports.readGlobalProjectsFile = readGlobalProjectsFile;
function saveGlobalProjectsFile(table) {
    return (0, file_1.saveTomlConfigFile)(constants_1.default.SPEC_GLOBAL_PROJECTS_PATH, table);
}
exports.saveGlobalProjectsFile = saveGlobalProjectsFile;
function saveProjectComposeEnvs(projectId, envs) {
    upsertSpecGlobalComposeDir();
    const envsFilePath = path_1.default.join(constants_1.default.SPEC_GLOBAL_COMPOSE_DIR, `${projectId}.env`);
    let contents = '';
    for (const key in envs) {
        contents += `${key}=${envs[key]}\n`;
    }
    let error;
    try {
        (0, file_1.createFileWithContents)(envsFilePath, contents);
    }
    catch (err) {
        error = `Error saving envs to path ${envsFilePath}: ${err}`;
    }
    return { path: envsFilePath, error };
}
exports.saveProjectComposeEnvs = saveProjectComposeEnvs;
//# sourceMappingURL=global.js.map