"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const env_1 = require("./utils/env");
const os_1 = __importDefault(require("os"));
const constants = {
    // Spec project config.
    SPEC_CONFIG_DIR_NAME: '.spec',
    CONNECTION_CONFIG_FILE_NAME: 'connect.toml',
    PROJECT_CONFIG_FILE_NAME: 'project.toml',
    MIGRATIONS_DIR_NAME: 'migrations',
    HANDLERS_DIR_NAME: 'handlers',
    HOOKS_DIR_NAME: 'hooks',
    GRAPHQL_DIR_NAME: 'graphql',
    DEFAULT_CONTRACT_GROUPS_SPEC_FILE_NAME: 'contracts.spec.json',
    DEFAULT_ABIS_FOLDER: 'abis',
    // Global CLI config.
    SPEC_GLOBAL_DIR: path_1.default.join(os_1.default.homedir(), '.spec'),
    SPEC_GLOBAL_STATE_FILE_NAME: 'state.toml',
    SPEC_GLOBAL_CREDS_FILE_NAME: 'creds.toml',
    SPEC_GLOBAL_PROJECTS_FILE_NAME: 'projects.toml',
    // Spec base/ecosystem and docs.
    SPEC_ORIGIN: (0, env_1.ev)('SPEC_ORIGIN', 'https://spec.dev'),
    DOCS_ORIGIN: (0, env_1.ev)('SPEC_DOCS_ORIGIN', 'https://docs.spec.dev'),
    // Spec API config.
    SPEC_API_ORIGIN: (0, env_1.ev)('SPEC_API_ORIGIN', 'https://api.spec.dev'),
    USER_AUTH_HEADER_NAME: 'Spec-User-Auth-Token',
    AUTH_HEADER_NAME: 'Spec-Auth-Token',
    // DB defaults.
    SPEC_DB_USER: 'spec',
    DB_PORT: 5432,
    QUICKSTART_DB_NAME: 'spec',
    // Live Table testing.
    LIVE_OBJECT_TESTING_DB_NAME: 'spec-test',
    LIVE_OBJECT_TESTING_API_PORT: 8000,
    // Desktop app name.
    SPEC_APP_NAME: 'Spec',
    // Default log size.
    DEFAULT_LOG_TAIL_SIZE: 20,
};
constants.SPEC_CONFIG_DIR = path_1.default.join(process.cwd(), constants.SPEC_CONFIG_DIR_NAME);
constants.CONNECTION_CONFIG_PATH = path_1.default.join(constants.SPEC_CONFIG_DIR, constants.CONNECTION_CONFIG_FILE_NAME);
constants.PROJECT_CONFIG_PATH = path_1.default.join(constants.SPEC_CONFIG_DIR, constants.PROJECT_CONFIG_FILE_NAME);
constants.SPEC_GLOBAL_STATE_PATH = path_1.default.join(constants.SPEC_GLOBAL_DIR, constants.SPEC_GLOBAL_STATE_FILE_NAME);
constants.SPEC_GLOBAL_CREDS_PATH = path_1.default.join(constants.SPEC_GLOBAL_DIR, constants.SPEC_GLOBAL_CREDS_FILE_NAME);
constants.SPEC_GLOBAL_PROJECTS_PATH = path_1.default.join(constants.SPEC_GLOBAL_DIR, constants.SPEC_GLOBAL_PROJECTS_FILE_NAME);
constants.SPEC_GLOBAL_COMPOSE_DIR = path_1.default.join(constants.SPEC_GLOBAL_DIR, 'compose');
constants.SPEC_HANDLERS_DIR = path_1.default.join(constants.SPEC_CONFIG_DIR, constants.HANDLERS_DIR_NAME);
constants.SPEC_HOOKS_DIR = path_1.default.join(constants.SPEC_CONFIG_DIR, constants.HOOKS_DIR_NAME);
exports.default = constants;
//# sourceMappingURL=constants.js.map