"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveAbi = void 0;
const logger_1 = require("../logger");
const validators_1 = require("./validators");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
function resolveAbi(abiOption) {
    if (!abiOption) {
        return { abi: null, isValid: true };
    }
    let abi = abiOption;
    if ((0, validators_1.isValidPath)(abi)) {
        // Try to read the ABI file in as JSON.
        try {
            abi = JSON.parse(fs_1.default.readFileSync(path_1.default.resolve(abiOption), 'utf8'));
        }
        catch (err) {
            (0, logger_1.logFailure)(`Error parsing ABI as JSON for path ${abiOption}: ${err.message}`);
            return { abi: null, isValid: false };
        }
        // Support hardhat/truffle artifacts.
        if (typeof abi === 'object' && !Array.isArray(abi) && abi.hasOwnProperty('abi')) {
            abi = abi.abi;
        }
    }
    else {
        try {
            abi = JSON.parse(abi);
        }
        catch (err) {
            (0, logger_1.logFailure)(`Error parsing ABI as JSON: ${err.message}`);
            return { abi: null, isValid: false };
        }
    }
    if (!Array.isArray(abi)) {
        (0, logger_1.logFailure)(`Invalid ABI: Expecting a JSON array.`);
        return { abi: null, isValid: false };
    }
    return { abi, isValid: true };
}
exports.resolveAbi = resolveAbi;
//# sourceMappingURL=abi.js.map