"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.followLocalLogs = exports.startSpec = exports.specClientInstalled = void 0;
const node_child_process_1 = require("node:child_process");
const constants_1 = __importDefault(require("../constants"));
const path_1 = __importDefault(require("path"));
const time_1 = require("./time");
const file_1 = require("./file");
const db_1 = require("../db");
const formatters_1 = require("../utils/formatters");
function specClientInstalled() {
    try {
        const out = (0, node_child_process_1.execSync)('which spec-client');
        const path = out.toString().trim();
        return !!path.length;
    }
    catch (error) {
        return false;
    }
}
exports.specClientInstalled = specClientInstalled;
function startSpec(projectId, specConfigDir, projectApiKey, dbConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data: connParams, error: formatError } = (0, db_1.resolveDBConnectionParams)(dbConfig);
        if (formatError)
            return { error: formatError };
        // Wipe any event cursors for now when running locally.
        const url = (0, formatters_1.asPostgresUrl)(connParams);
        (0, db_1.clearEventCursors)(url);
        const args = [
            ['--config-dir', specConfigDir],
            ['--user', connParams.user],
            ['--host', connParams.host],
            ['--port', connParams.port],
            ['--name', connParams.name],
            ['--id', projectId],
            ['--api-key', projectApiKey],
            ['--debug', 'true'],
        ].flat();
        if (connParams.password) {
            args.push(...['--password', connParams.password]);
        }
        try {
            (0, node_child_process_1.execSync)(`spec-client ${args.join(' ')}`, { stdio: 'inherit' });
        }
        catch (error) {
            return { error };
        }
        return { error: null };
    });
}
exports.startSpec = startSpec;
function followLocalLogs(projectId, tail) {
    return __awaiter(this, void 0, void 0, function* () {
        const logFilePath = path_1.default.join(constants_1.default.SPEC_GLOBAL_DIR, `${projectId}.log`);
        while (!(0, file_1.fileExists)(logFilePath)) {
            yield (0, time_1.sleep)(100);
        }
        try {
            (0, node_child_process_1.execSync)(`tail -n ${tail} -f ${logFilePath}`, { stdio: 'inherit' });
        }
        catch (error) {
            return { error };
        }
        return { error: null };
    });
}
exports.followLocalLogs = followLocalLogs;
//# sourceMappingURL=client.js.map