"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.narrowColType = exports.TIMESTAMPTZ = exports.TIMESTAMP_WITH_TIME_ZONE = exports.TIMESTAMP_WITHOUT_TIME_ZONE = exports.TIMESTAMP = exports.TIMETZ = exports.TIME_WITH_TIME_ZONE = exports.TIME_WITHOUT_TIME_ZONE = exports.TIME = exports.DATE = exports.JSONB = exports.JSON = exports.TEXT = exports.CHARACTER_VARYING = exports.VARCHAR = exports.CHARACTER = exports.CHAR = exports.BOOLEAN = exports.BOOL = exports.SERIAL8 = exports.SERIAL4 = exports.SERIAL2 = exports.BIGSERIAL = exports.SERIAL = exports.SMALLSERIAL = exports.FLOAT8 = exports.FLOAT4 = exports.DOUBLE_PRECISION = exports.REAL = exports.NUMERIC = exports.DECIMAL = exports.INT8 = exports.INT4 = exports.INT2 = exports.BIGINT = exports.INTEGER = exports.SMALLINT = exports.INT = void 0;
// Integer Types
exports.INT = 'int';
exports.SMALLINT = 'smallint';
exports.INTEGER = 'integer';
exports.BIGINT = 'bigint';
exports.INT2 = 'int2';
exports.INT4 = 'int4';
exports.INT8 = 'int8';
// Arbitrary Precision Numbers
exports.DECIMAL = 'decimal';
exports.NUMERIC = 'numeric';
// Floating-Point Types
exports.REAL = 'real';
exports.DOUBLE_PRECISION = 'double precision';
exports.FLOAT4 = 'float4';
exports.FLOAT8 = 'float8';
// Serial Types
exports.SMALLSERIAL = 'smallserial';
exports.SERIAL = 'serial';
exports.BIGSERIAL = 'bigserial';
exports.SERIAL2 = 'serial2';
exports.SERIAL4 = 'serial4';
exports.SERIAL8 = 'serial8';
// Boolean Type
exports.BOOL = 'bool';
exports.BOOLEAN = 'boolean';
// Character Types
exports.CHAR = 'char';
exports.CHARACTER = 'character';
exports.VARCHAR = 'varchar';
exports.CHARACTER_VARYING = 'character varying';
exports.TEXT = 'text';
// JSON Types
exports.JSON = 'json';
exports.JSONB = 'jsonb';
// Date/Time Types
exports.DATE = 'date';
exports.TIME = 'time';
exports.TIME_WITHOUT_TIME_ZONE = 'time without time zone';
exports.TIME_WITH_TIME_ZONE = 'time with time zone';
exports.TIMETZ = 'timetz';
exports.TIMESTAMP = 'timestamp';
exports.TIMESTAMP_WITHOUT_TIME_ZONE = 'timestamp without time zone';
exports.TIMESTAMP_WITH_TIME_ZONE = 'timestamp with time zone';
exports.TIMESTAMPTZ = 'timestamptz';
function narrowColType(t) {
    t = t || '';
    // int2
    if ([exports.SMALLINT, exports.INT2].includes(t)) {
        return exports.INT2;
    }
    // int4
    if ([exports.INTEGER, exports.INT, exports.INT4].includes(t)) {
        return exports.INT4;
    }
    // int8
    if ([exports.BIGINT, exports.INT8].includes(t)) {
        return exports.INT8;
    }
    // numeric
    if (!!t.match(new RegExp(`(${exports.NUMERIC}|${exports.DECIMAL})`, 'gi'))) {
        return exports.NUMERIC;
    }
    // float4
    if (!!t.match(new RegExp(`(${exports.REAL}|${exports.FLOAT4})`, 'gi'))) {
        return exports.FLOAT4;
    }
    // float8
    if (!!t.match(new RegExp(`(${exports.DOUBLE_PRECISION}|${exports.FLOAT8})`, 'gi'))) {
        return exports.FLOAT8;
    }
    // boolean
    if ([exports.BOOL, exports.BOOLEAN].includes(t)) {
        return exports.BOOLEAN;
    }
    // varchar
    if (!!t.match(new RegExp(`(${exports.CHARACTER_VARYING}|${exports.VARCHAR})`, 'gi'))) {
        return exports.VARCHAR;
    }
    // char
    if (!!t.match(new RegExp(`(${exports.CHARACTER}|${exports.CHAR})`, 'gi'))) {
        return exports.CHAR;
    }
    // text
    if (t === exports.TEXT) {
        return exports.TEXT;
    }
    // json
    if (t === exports.JSON) {
        return exports.JSON;
    }
    // jsonb
    if (t === exports.JSONB) {
        return exports.JSONB;
    }
    // date
    if (t === exports.DATE) {
        return exports.DATE;
    }
    // timestamptz
    if (!!t.match(new RegExp(`(${exports.TIMESTAMP_WITH_TIME_ZONE}|${exports.TIMESTAMPTZ})`, 'gi'))) {
        return exports.TIMESTAMPTZ;
    }
    // timestamp
    if (!!t.match(new RegExp(`(${exports.TIMESTAMP_WITHOUT_TIME_ZONE}|${exports.TIMESTAMP})`, 'gi'))) {
        return exports.TIMESTAMP;
    }
    // timetz
    if (!!t.match(new RegExp(`(${exports.TIME_WITH_TIME_ZONE}|${exports.TIMETZ})`, 'gi'))) {
        return exports.TIMETZ;
    }
    // time
    if (!!t.match(new RegExp(`(${exports.TIME_WITHOUT_TIME_ZONE}|${exports.TIME})`, 'gi'))) {
        return exports.TIME;
    }
    // Anything else
    return t;
}
exports.narrowColType = narrowColType;
//# sourceMappingURL=columnTypes.js.map