"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.testLiveObject = exports.cacheDenoTestFile = exports.hasCachedDenoTestFile = exports.ensureDenoInstalled = void 0;
const node_child_process_1 = require("node:child_process");
const constants_1 = __importDefault(require("../constants"));
const path_1 = __importDefault(require("path"));
const db_1 = require("../db");
const process_1 = __importDefault(require("process"));
const global_1 = require("../config/global");
const version_1 = require("../version");
const logger_1 = require("../logger");
const testLiveObjectFilePath = path_1.default.resolve(__dirname, '..', 'files', 'testLiveObject.ts');
function ensureDenoInstalled() {
    try {
        const out = (0, node_child_process_1.execSync)('which deno');
        const path = out.toString().trim();
        return !!path.length;
    }
    catch (error) {
        return false;
    }
}
exports.ensureDenoInstalled = ensureDenoInstalled;
function hasCachedDenoTestFile() {
    var _a, _b;
    return ((_b = (_a = (0, global_1.readGlobalStateFile)()) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.version) === version_1.version;
}
exports.hasCachedDenoTestFile = hasCachedDenoTestFile;
function cacheDenoTestFile() {
    (0, logger_1.log)(`Caching live object test file...`);
    try {
        (0, node_child_process_1.execSync)(`deno cache ${testLiveObjectFilePath}`, { stdio: 'inherit' });
    }
    catch (error) {
        return { error };
    }
    (0, global_1.saveState)({ version: version_1.version });
}
exports.cacheDenoTestFile = cacheDenoTestFile;
function testLiveObject(liveObjectFolderName, options, apiKey) {
    return __awaiter(this, void 0, void 0, function* () {
        const { data: user } = (0, db_1.getCurrentDbUser)();
        if (!user) {
            return { error: `No current DB user could be found.` };
        }
        hasCachedDenoTestFile() || cacheDenoTestFile();
        const liveObjectTestingDbUrl = process_1.default.env.LIVE_OBJECT_TESTING_DB_URL ||
            `postgres://${user}:@localhost:5432/${constants_1.default.LIVE_OBJECT_TESTING_DB_NAME}`;
        const { recent, from, fromBlock, to, toBlock, chains, allTime, keepData, port } = options;
        const cmdArgs = [
            '--cached-only',
            '--allow-env',
            '--allow-net',
            '--allow-read',
            '--importmap=imports.json',
            testLiveObjectFilePath,
            liveObjectFolderName,
            liveObjectTestingDbUrl,
            constants_1.default.SPEC_API_ORIGIN,
            recent ? recent.toString() : 'false',
            from ? from.toISOString() : 'null',
            fromBlock ? fromBlock.toString() : 'null',
            to ? to.toISOString() : 'null',
            toBlock ? toBlock.toString() : 'null',
            chains ? chains.toString() : 'null',
            allTime ? allTime.toString() : 'false',
            keepData ? keepData.toString() : 'false',
            port ? port.toString() : 'null',
            apiKey ? apiKey : 'null',
        ];
        process_1.default.env.SHARED_TABLES_ORIGIN = `http://localhost:${options.port}`;
        process_1.default.env.SPEC_RPC_AUTH_TOKEN = apiKey;
        try {
            (0, node_child_process_1.execSync)(`deno run ${cmdArgs.join(' ')}`, { stdio: 'inherit' });
        }
        catch (error) {
            return { error };
        }
        return { error: null };
    });
}
exports.testLiveObject = testLiveObject;
//# sourceMappingURL=deno.js.map