"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveTomlConfigFile = exports.readTomlConfigFile = exports.getFileLines = exports.isDir = exports.getContentsOfFolder = exports.tmpdir = exports.createFileWithContents = exports.createDir = exports.fileExists = void 0;
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const j_toml_1 = __importDefault(require("@ltd/j-toml"));
const fileExists = (path) => fs_1.default.existsSync(path);
exports.fileExists = fileExists;
const createDir = (path) => fs_1.default.mkdirSync(path);
exports.createDir = createDir;
const createFileWithContents = (path, contents) => fs_1.default.writeFileSync(path, contents);
exports.createFileWithContents = createFileWithContents;
const tmpdir = () => os_1.default.tmpdir();
exports.tmpdir = tmpdir;
const getContentsOfFolder = (path) => fs_1.default.readdirSync(path);
exports.getContentsOfFolder = getContentsOfFolder;
const isDir = (path) => fs_1.default.statSync(path).isDirectory();
exports.isDir = isDir;
const getFileLines = (path) => {
    try {
        const contents = fs_1.default.readFileSync(path, 'utf-8') || '';
        return contents.split('\n');
    }
    catch (err) {
        return [];
    }
};
exports.getFileLines = getFileLines;
function readTomlConfigFile(path) {
    if (!(0, exports.fileExists)(path)) {
        return { data: {} };
    }
    try {
        const data = j_toml_1.default.parse(fs_1.default.readFileSync(path, 'utf-8'));
        return { data };
    }
    catch (error) {
        return { error };
    }
}
exports.readTomlConfigFile = readTomlConfigFile;
function saveTomlConfigFile(path, table) {
    let error;
    try {
        (0, exports.createFileWithContents)(path, j_toml_1.default.stringify(table, { newlineAround: 'section', newline: '\n' }));
    }
    catch (err) {
        error = err;
    }
    return { error };
}
exports.saveTomlConfigFile = saveTomlConfigFile;
//# sourceMappingURL=file.js.map