"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.toContractGroupsUrl = exports.toLiveTableUrl = exports.toSpecNamespaceUrl = exports.toNamespaceSlug = exports.fromNamespacedVersion = exports.removeAcronymFromCamel = exports.camelToSnake = exports.asPostgresUrl = exports.toDate = exports.toNumber = exports.capitalize = exports.unique = exports.toNamespacedVersion = exports.toMap = exports.repoPathToComponents = exports.removeTrailingSlash = void 0;
const humps_1 = __importDefault(require("humps"));
const constants_1 = __importDefault(require("../constants"));
function removeTrailingSlash(str) {
    return str.replace(/\/+$/, '');
}
exports.removeTrailingSlash = removeTrailingSlash;
function repoPathToComponents(path) {
    const splitPath = path.split('/');
    return splitPath.length === 2 ? splitPath : null;
}
exports.repoPathToComponents = repoPathToComponents;
function toMap(obj) {
    const newObj = {};
    for (let key in obj) {
        newObj[key] = obj[key];
    }
    return newObj;
}
exports.toMap = toMap;
const toNamespacedVersion = (nsp, name, version) => `${nsp}.${name}@${version}`;
exports.toNamespacedVersion = toNamespacedVersion;
const unique = (arr) => Array.from(new Set(arr));
exports.unique = unique;
const capitalize = (val) => {
    const firstLetter = val[0].toUpperCase();
    return `${firstLetter}${val.slice(1)}`;
};
exports.capitalize = capitalize;
const toNumber = (val) => {
    const num = parseInt(val);
    return Number.isNaN(num) ? null : num;
};
exports.toNumber = toNumber;
const toDate = (val) => {
    const date = new Date(val);
    const invalid = date.toString().toLowerCase() === 'invalid date';
    return invalid ? null : date;
};
exports.toDate = toDate;
const asPostgresUrl = (connParams) => {
    const { user, password, host, port, name } = connParams;
    return `postgres://${user}:${password}@${host}:${port}/${name}`;
};
exports.asPostgresUrl = asPostgresUrl;
const camelToSnake = (val) => {
    return humps_1.default.decamelize((0, exports.removeAcronymFromCamel)(val));
};
exports.camelToSnake = camelToSnake;
const removeAcronymFromCamel = (val) => {
    val = val || '';
    let formattedVal = '';
    for (let i = 0; i < val.length; i++) {
        const [prevChar, char, nextChar] = [val[i - 1], val[i], val[i + 1]];
        const [prevCharIsUpperCase, charIsUpperCase, nextCharIsUpperCase] = [
            prevChar && prevChar === prevChar.toUpperCase(),
            char && char === char.toUpperCase(),
            nextChar && nextChar === nextChar.toUpperCase(),
        ];
        if (prevCharIsUpperCase &&
            charIsUpperCase &&
            (nextCharIsUpperCase || i === val.length - 1)) {
            formattedVal += char.toLowerCase();
        }
        else {
            formattedVal += char;
        }
    }
    return formattedVal;
};
exports.removeAcronymFromCamel = removeAcronymFromCamel;
const fromNamespacedVersion = (namespacedVersion) => {
    const atSplit = (namespacedVersion || '').split('@');
    if (atSplit.length !== 2) {
        return { nsp: '', name: '', version: '' };
    }
    const [nspName, version] = atSplit;
    const dotSplit = (nspName || '').split('.');
    if (dotSplit.length < 2) {
        return { nsp: '', name: '', version: '' };
    }
    const name = dotSplit.pop();
    const nsp = dotSplit.join('.');
    return { nsp, name, version };
};
exports.fromNamespacedVersion = fromNamespacedVersion;
const toNamespaceSlug = (value) => {
    return value
        .replace(/[']/g, '')
        .replace(/[^A-Za-z0-9-_.]/g, '-')
        .toLowerCase();
};
exports.toNamespaceSlug = toNamespaceSlug;
const toSpecNamespaceUrl = (nsp) => [constants_1.default.SPEC_ORIGIN, nsp].join('/');
exports.toSpecNamespaceUrl = toSpecNamespaceUrl;
const toLiveTableUrl = (nsp, uid) => `https://spec.dev/${nsp}/live-table/${uid}`;
exports.toLiveTableUrl = toLiveTableUrl;
const toContractGroupsUrl = (nsp) => `https://spec.dev/${nsp}/contract-groups`;
exports.toContractGroupsUrl = toContractGroupsUrl;
//# sourceMappingURL=formatters.js.map