"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.promptAddContractsDetails = exports.promptCreateContractGroupDetails = exports.promptNewLiveObjectDetails = exports.promptEmailPassword = void 0;
const qoa_1 = __importDefault(require("qoa"));
const chalk_1 = __importDefault(require("chalk"));
const EMAIL_PROMPT = {
    type: 'input',
    query: 'Email:',
    handle: 'email',
};
const PASSWORD_PROMPT = {
    type: 'secure',
    query: 'Password:',
    handle: 'password',
};
const NAMESPACE_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.cyanBright('*')} Namespace:`,
    handle: 'namespace',
};
const NAME_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.cyanBright('*')} Name:`,
    handle: 'name',
};
const CHAIN_IDS_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.cyanBright('*')} Chain ids ${chalk_1.default.gray(`(e.g. "1, 5, 137"):`)}`,
    handle: 'chainIds',
};
const CHAIN_ID_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.cyanBright('*')} Chain id ${chalk_1.default.gray(`(e.g. "1"):`)}`,
    handle: 'chainId',
};
const DISPLAY_NAME_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.gray('?')} Display name ${chalk_1.default.gray('(optional):')}`,
    handle: 'displayName',
};
const DESCRIPTION_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.gray('?')} Description ${chalk_1.default.gray('(optional):')}`,
    handle: 'description',
};
const CONTRACT_GROUP_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.cyanBright('*')} Group name ${chalk_1.default.gray(`(e.g. "gitcoin.GovernorAlpha"):`)}`,
    handle: 'group',
};
const ABI_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.cyanBright('*')} Path to ABI ${chalk_1.default.gray(`(e.g. "./abis/Contract.json"):`)}`,
    handle: 'abi',
};
const OPTIONAL_ABI_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.gray('?')} Path to ABI ${chalk_1.default.gray('(optional if group already exists):')}`,
    handle: 'abi',
};
const CONTRACT_ADDRESSES_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.cyanBright('*')} Contract addresses ${chalk_1.default.gray(`(e.g. "0xabc, 0x123"):`)}`,
    handle: 'addresses',
};
const IS_FACTORY_GROUP_PROMPT = {
    type: 'input',
    query: `${chalk_1.default.gray('?')} Will this group hold contracts created by a factory? ${chalk_1.default.gray(`(y/n):`)}`,
    handle: 'isFactoryGroup',
};
function stripWrappedQuotes(val) {
    if (!val)
        return val;
    if (val[0] === '"') {
        val = val.slice(1);
    }
    if (val[val.length - 1] === '"') {
        val = val.slice(0, val.length - 1);
    }
    return val;
}
function promptEmailPassword() {
    return __awaiter(this, void 0, void 0, function* () {
        let email = '';
        while (!email) {
            email = (yield qoa_1.default.prompt([EMAIL_PROMPT])).email;
        }
        let password = '';
        while (!password) {
            password = (yield qoa_1.default.prompt([PASSWORD_PROMPT])).password;
        }
        return { email, password };
    });
}
exports.promptEmailPassword = promptEmailPassword;
function promptNewLiveObjectDetails(namespace, name) {
    return __awaiter(this, void 0, void 0, function* () {
        // Required
        while (!namespace) {
            namespace = (yield qoa_1.default.prompt([NAMESPACE_PROMPT])).namespace;
        }
        // Required
        while (!name) {
            name = (yield qoa_1.default.prompt([NAME_PROMPT])).name;
        }
        // Optional
        const displayName = (yield qoa_1.default.prompt([DISPLAY_NAME_PROMPT])).displayName;
        const description = (yield qoa_1.default.prompt([DESCRIPTION_PROMPT])).description;
        return {
            namespace,
            name,
            displayName,
            description,
        };
    });
}
exports.promptNewLiveObjectDetails = promptNewLiveObjectDetails;
function promptCreateContractGroupDetails(group, abi, isFactoryGroup) {
    return __awaiter(this, void 0, void 0, function* () {
        // Required
        while (!group) {
            group = stripWrappedQuotes((yield qoa_1.default.prompt([CONTRACT_GROUP_PROMPT])).group);
        }
        // Required
        while (!abi) {
            abi = stripWrappedQuotes((yield qoa_1.default.prompt([ABI_PROMPT])).abi);
        }
        if (typeof isFactoryGroup !== 'boolean') {
            const answer = ((yield qoa_1.default.prompt([IS_FACTORY_GROUP_PROMPT])).isFactoryGroup || '')
                .toLowerCase()
                .trim();
            isFactoryGroup = ['y', 'yes'].includes(answer);
        }
        return { group, abi, isFactoryGroup };
    });
}
exports.promptCreateContractGroupDetails = promptCreateContractGroupDetails;
function promptAddContractsDetails(addresses, chainId, group, abi) {
    return __awaiter(this, void 0, void 0, function* () {
        // Required
        while (!chainId) {
            chainId = stripWrappedQuotes((yield qoa_1.default.prompt([CHAIN_ID_PROMPT])).chainId);
        }
        // Required
        while (!addresses) {
            addresses = stripWrappedQuotes((yield qoa_1.default.prompt([CONTRACT_ADDRESSES_PROMPT])).addresses);
        }
        // Required
        while (!group) {
            group = stripWrappedQuotes((yield qoa_1.default.prompt([CONTRACT_GROUP_PROMPT])).group);
        }
        // Optional
        abi = abi || stripWrappedQuotes((yield qoa_1.default.prompt([OPTIONAL_ABI_PROMPT])).abi);
        return { addresses, chainId, group, abi };
    });
}
exports.promptAddContractsDetails = promptAddContractsDetails;
//# sourceMappingURL=prompt.js.map