"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.post = exports.get = void 0;
const node_fetch_1 = __importDefault(require("node-fetch"));
function get(url, args, headers, returnRawResponse) {
    return __awaiter(this, void 0, void 0, function* () {
        const params = new URLSearchParams();
        for (let key in args) {
            params.append(key, args[key]);
        }
        let resp, err;
        try {
            resp = yield (0, node_fetch_1.default)(`${url}?${params.toString()}`, { headers });
        }
        catch (err) {
            err = err;
        }
        if (err)
            return { error: err };
        if (returnRawResponse) {
            return { data: resp };
        }
        const { data, error } = yield parseJSONResp(resp);
        if (error)
            return { error };
        return {
            data,
            headers: resp.headers,
        };
    });
}
exports.get = get;
function post(url, payload, headers) {
    return __awaiter(this, void 0, void 0, function* () {
        let resp, err;
        try {
            resp = yield (0, node_fetch_1.default)(url, {
                method: 'POST',
                body: JSON.stringify(payload),
                headers: Object.assign({ 'Content-Type': 'application/json' }, (headers || {})),
            });
        }
        catch (err) {
            err = err;
        }
        if (err)
            return { error: err };
        const { data, error } = yield parseJSONResp(resp);
        if (error)
            return { error };
        return {
            data,
            headers: resp.headers,
        };
    });
}
exports.post = post;
function parseJSONResp(resp) {
    return __awaiter(this, void 0, void 0, function* () {
        let data = {};
        try {
            data = yield resp.json();
        }
        catch (err) {
            return { error: `Error parsing JSON response: ${err}.` };
        }
        if (data.error) {
            return { error: data.error };
        }
        if (resp.status !== 200) {
            return { error: `Request failed with status ${resp.status}.` };
        }
        return { data };
    });
}
//# sourceMappingURL=request.js.map